==> GameboyVM-Project-0.06.zip: win32/GBEmuDlg.h <==
// GBEmuDlg.h : wb_[ t@C
//

#if !defined(AFX_GBEMUDLG_H__D633E966_73A6_11D6_99ED_004026569E1B__INCLUDED_)
#define AFX_GBEMUDLG_H__D633E966_73A6_11D6_99ED_004026569E1B__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "TilesDlg.h"
#include "Maps.h"
#include "MemDlg.h"
#include "Disasm.h"
#include "ObjDlg.h"
#include "KeyDlg.h"
#include "DmaDlg.h"
#include <mmsystem.h>

/////////////////////////////////////////////////////////////////////////////
// CGBEmuDlg _CAO

class CGBEmuDlg : public CDialog
{
// \z
public:
	CGBEmuDlg(CWnd* pParent = NULL);	// W̃RXgN^
	static UINT ThreadMain(LPVOID pParam);
	static UINT ThreadGUI(LPVOID pParam);
	void OnOK();
	void OnCancel();
	void MainLoop();	/*G~[^̃C[v*/
	void UpdateGUI();	/*fobK̍XV*/
	void ShowFps();		/*t[b\*/
	void DrawLCD();		/*LCD̃_O*/
	void PlayGBSound();	/*TEh̍XV*/
	void DebugNextStep();	/*C[vꎞ~iXebvsj*/
	void DebugBreakPoint();	/*C[vɃu[N|Cg𒣂*/
	void WaitForTMain();	/*C[vXbh̏I҂*/
	bool fTMain;			/*C[vXbh̓tO*/
	CTilesDlg* m_pTileDlg;	/*_CAONX|C^̐錾*/
	CMaps* m_pMapDlg;
	CMemDlg* m_pMemDlg;
	CDisasm* m_pDasm;
	CObjDlg* m_pObjDlg;
	CKeyDlg* m_pKeyDlg;
	CDmaDlg* m_pDmaDlg;
	JOYINFO	joyinfo;
	JOYCAPS	joycaps;

// _CAO f[^
	//{{AFX_DATA(CGBEmuDlg)
	enum { IDD = IDD_GBEMU_DIALOG };
		// : ̈ʒu ClassWizard ɂăf[^ oǉ܂B
	//}}AFX_DATA

	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CGBEmuDlg)
	public:
	virtual BOOL PreTranslateMessage(MSG* pMsg);
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);	// DDX/DDV ̃T|[g
	//}}AFX_VIRTUAL

// Cve[V
protected:
	HICON m_hIcon;

	CWinThread* m_pTMain;		// MainLooppXbh̃|C^
	CWinThread* m_pTGUI;

	// ꂽbZ[W }bv֐
	//{{AFX_MSG(CGBEmuDlg)
	virtual BOOL OnInitDialog();
	afx_msg void OnPaint();
	afx_msg HCURSOR OnQueryDragIcon();
	afx_msg void OnMenuExit();
	afx_msg void OnMenuAbout();
	afx_msg void OnMenuOpen();
	afx_msg void OnMenuReset();
	afx_msg void OnShowFps();
	afx_msg void OnClose();
	afx_msg void OnPriorityNormal();
	afx_msg void OnPriorityHighest();
	afx_msg void OnPriorityLowest();
	afx_msg void OnPriorityAbove();
	afx_msg void OnPriorityBelow();
	afx_msg void OnShowTiles();
	afx_msg void OnShowMap();
	afx_msg void OnVsync();
	afx_msg void OnDropFiles(HDROP hDropInfo);
	afx_msg void OnShowMemory();
	afx_msg void OnSize(UINT nType, int cx, int cy);
	afx_msg void OnZoom1();
	afx_msg void OnZoom2();
	afx_msg void OnZoom3();
	afx_msg void OnZoom4();
	afx_msg void OnShowDebug();
	afx_msg void OnActivate(UINT nState, CWnd* pWndOther, BOOL bMinimized);
	afx_msg void OnSkip0();
	afx_msg void OnSkip5();
	afx_msg void OnSkip1();
	afx_msg void OnSkip2();
	afx_msg void OnSkip3();
	afx_msg void OnSkip4();
	afx_msg void OnLayerBg();
	afx_msg void OnLayerObj();
	afx_msg void OnLayerWnd();
	afx_msg void OnPalette1();
	afx_msg void OnPalette2();
	afx_msg void OnPalette3();
	afx_msg void OnMenuDisableAll();
	afx_msg void OnShowOam();
	afx_msg void OnSoundEnable();
	afx_msg void OnMenu16bitdib();
	afx_msg void OnMenu8bitdib();
	afx_msg void OnSoundCh1();
	afx_msg void OnSoundCh2();
	afx_msg void OnSoundCh3();
	afx_msg void OnMenuKey();
	afx_msg void OnZoomFull();
	afx_msg int OnCreate(LPCREATESTRUCT lpCreateStruct);
	afx_msg void OnFilterNormal();
	afx_msg void OnFilter2xsai();
	afx_msg void OnFilterSuper2xsai();
	afx_msg void OnFilterSupereagle();
	afx_msg void OnDmaDump();
	afx_msg void OnHeaderInfo();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_GBEMUDLG_H__D633E966_73A6_11D6_99ED_004026569E1B__INCLUDED_)

==> GameboyVM-Project-0.07.zip: win32/GBEmuDlg.h <==
// GBEmuDlg.h : wb_[ t@C
//

#if !defined(AFX_GBEMUDLG_H__D633E966_73A6_11D6_99ED_004026569E1B__INCLUDED_)
#define AFX_GBEMUDLG_H__D633E966_73A6_11D6_99ED_004026569E1B__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "TilesDlg.h"
#include "Maps.h"
#include "MemDlg.h"
#include "Disasm.h"
#include "ObjDlg.h"
#include "KeyDlg.h"
#include "DmaDlg.h"
#include <mmsystem.h>

/////////////////////////////////////////////////////////////////////////////
// CGBEmuDlg _CAO

class CGBEmuDlg : public CDialog
{
// \z
public:
	CGBEmuDlg(CWnd* pParent = NULL);	// W̃RXgN^
	static UINT ThreadMain(LPVOID pParam);
	static UINT ThreadGUI(LPVOID pParam);
	void OnOK();
	void OnCancel();
	void MainLoop();	/*G~[^̃C[v*/
	void UpdateGUI();	/*fobK̍XV*/
	_inline void ShowFps();		/*t[b\*/
	/*_inline */void DrawLCD();		/*LCD̃_O*/
	void PlayGBSound();	/*TEh̍XV*/
	void DebugNextStep();	/*C[vꎞ~iXebvsj*/
	void DebugBreakPoint();	/*C[vɃu[N|Cg𒣂*/
	void WaitForTMain();	/*C[vXbh̏I҂*/
	bool fTMain;			/*C[vXbh̓tO*/
	CTilesDlg* m_pTileDlg;	/*_CAONX|C^̐錾*/
	CMaps* m_pMapDlg;
	CMemDlg* m_pMemDlg;
	CDisasm* m_pDasm;
	CObjDlg* m_pObjDlg;
	CKeyDlg* m_pKeyDlg;
	CDmaDlg* m_pDmaDlg;
	JOYINFO	joyinfo;
	JOYCAPS	joycaps;
	bool fAutoSave, fAutoLoad;
	bool Os9x;
	int  iZoom;
	UINT iFilter;
	CString FilePath;
	void InitializeKeyCode();

// _CAO f[^
	//{{AFX_DATA(CGBEmuDlg)
	enum { IDD = IDD_GBEMU_DIALOG };
		// : ̈ʒu ClassWizard ɂăf[^ oǉ܂B
	//}}AFX_DATA

	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CGBEmuDlg)
	public:
	virtual BOOL PreTranslateMessage(MSG* pMsg);
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);	// DDX/DDV ̃T|[g
	//}}AFX_VIRTUAL

// Cve[V
protected:
	HICON m_hIcon;

	CWinThread* m_pTMain;		// MainLooppXbh̃|C^
	CWinThread* m_pTGUI;

	// ꂽbZ[W }bv֐
	//{{AFX_MSG(CGBEmuDlg)
	virtual BOOL OnInitDialog();
	afx_msg void OnPaint();
	afx_msg HCURSOR OnQueryDragIcon();
	afx_msg void OnMenuExit();
	afx_msg void OnMenuAbout();
	afx_msg void OnMenuOpen();
	afx_msg void OnMenuReset();
	afx_msg void OnShowFps();
	afx_msg void OnClose();
	afx_msg void OnPriorityNormal();
	afx_msg void OnPriorityHighest();
	afx_msg void OnPriorityLowest();
	afx_msg void OnPriorityAbove();
	afx_msg void OnPriorityBelow();
	afx_msg void OnShowTiles();
	afx_msg void OnShowMap();
	afx_msg void OnVsync();
	afx_msg void OnDropFiles(HDROP hDropInfo);
	afx_msg void OnShowMemory();
	afx_msg void OnSize(UINT nType, int cx, int cy);
	afx_msg void OnZoom1();
	afx_msg void OnZoom2();
	afx_msg void OnZoom3();
	afx_msg void OnZoom4();
	afx_msg void OnShowDebug();
	afx_msg void OnActivate(UINT nState, CWnd* pWndOther, BOOL bMinimized);
	afx_msg void OnSkip0();
	afx_msg void OnSkip5();
	afx_msg void OnSkip1();
	afx_msg void OnSkip2();
	afx_msg void OnSkip3();
	afx_msg void OnSkip4();
	afx_msg void OnLayerBg();
	afx_msg void OnLayerObj();
	afx_msg void OnLayerWnd();
	afx_msg void OnPalette1();
	afx_msg void OnPalette2();
	afx_msg void OnPalette3();
	afx_msg void OnMenuDisableAll();
	afx_msg void OnShowOam();
	afx_msg void OnSoundEnable();
	afx_msg void OnMenu16bitdib();
	afx_msg void OnMenu8bitdib();
	afx_msg void OnSoundCh1();
	afx_msg void OnSoundCh2();
	afx_msg void OnSoundCh3();
	afx_msg void OnMenuKey();
	afx_msg void OnZoomFull();
	afx_msg int OnCreate(LPCREATESTRUCT lpCreateStruct);
	afx_msg void OnFilterNormal();
	afx_msg void OnFilter2xsai();
	afx_msg void OnFilterSuper2xsai();
	afx_msg void OnFilterSupereagle();
	afx_msg void OnDmaDump();
	afx_msg void OnHeaderInfo();
	afx_msg void OnFilterPixelate();
	afx_msg void OnFilterMotionblur();
	afx_msg void OnFilterTvmode();
	afx_msg void OnLoad();
	afx_msg void OnSave();
	afx_msg void OnAutoSave();
	afx_msg void OnAutoLoad();
	afx_msg void OnModeAuto();
	afx_msg void OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnModeColor();
	afx_msg void OnClassic();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_GBEMUDLG_H__D633E966_73A6_11D6_99ED_004026569E1B__INCLUDED_)
